@@ -3,33 +3,41 @@
 #' Counts how many quartets are resolved or unresolved in a given tree, 
 #' following Brodal _et al._ (2013).
 #' 
+#' Trees with more than 477 leaves risk encountering integer overflow errors,
+#' as the number of quartets is larger than can be stored in R's signed 
+#' 32-bit integer representation.  If warnings are thrown, check subsequent
+#' calculations for errors.
+#' 
 #' @template treeParam
 #' @param countTriplets Logical; if `TRUE`, the function will return the number
 #' of triplets instead of the number of quartets.
 #' 
-#' @return A vector of length two, listing the number of quartets (or triplets)
+#' @return `ResolvedQuartets()` returns a vector of length two, listing the
+#' number of quartets (or triplets)
 #'  that are \[1\] resolved; \[2\] unresolved in the specified tree.
 #'         
 #' @template MRS
 #' 
 #' @family quartet counting functions
 #' 
-#' @examples {
-#'   data(sq_trees)
-#'   
-#'   ResolvedTriplets(sq_trees$collapse_some)
-#'   # Equivalent to:
-#'   ResolvedQuartets(sq_trees$collapse_some, countTriplets=TRUE)
-#'   
-#'   vapply(sq_trees, ResolvedQuartets, integer(2))
-#' }
+#' @examples
+#' data(sq_trees)
 #' 
-#' @references \insertRef{Brodal2013}{Quartet}
+#' ResolvedTriplets(sq_trees$collapse_some)
+#' # Equivalent to:
+#' ResolvedQuartets(sq_trees$collapse_some, countTriplets = TRUE)
 #' 
-## @importFrom TreeTools Renumber
+#' vapply(sq_trees, ResolvedQuartets, integer(2))
+#'
+#' 
+#' @references
+#' - \insertRef{Brodal2013}{Quartet}
+#' 
+#' @importFrom TreeTools Preorder
 #' @export 
 ResolvedQuartets <- function (tree, countTriplets = FALSE) {
-  #tree <- Renumber(tree)
+  .CheckSize(tree)
+  tree <- Preorder(tree)
   nTip <- length(tree$tip.label)
   nNode <- tree$Nnode
   
@@ -67,12 +75,21 @@ ResolvedQuartets <- function (tree, countTriplets = FALSE) {
   unresolved <- ifelse(countTriplets, sum(unresolvedTripletsRootedHere),
                            sum(unresolvedQuartetsRootedHere))
   resolved <- choose(nTip, ifelse(countTriplets, 3, 4)) - unresolved
+  
+  if (any(c(resolved, unresolved) > .Machine$integer.max)) {
+    stop("Sorry: trees too large for integer representation")
+  } else if (resolved + unresolved > .Machine$integer.max) {
+    warning("Large numbers: integer overflow likely")
+  }
+    
   # Return:
   as.integer(c(resolved, unresolved))
+
 }
 
 
 #' @describeIn ResolvedQuartets Convenience function to calculate the number of 
 #' resolved/unresolved triplets.
 #' @export
-ResolvedTriplets <- function (tree) ResolvedQuartets(tree=tree, countTriplets=TRUE)
\ No newline at end of file
+ResolvedTriplets <- function (tree) ResolvedQuartets(tree = tree,
+                                                     countTriplets = TRUE)
