@@ -1,9 +1,10 @@
 test_that("VizualiseQuartets()", {
-  expect_doppelganger("VQ-label", function() {
+  skip_if_not_installed('vdiffr')
+  vdiffr::expect_doppelganger("VQ-label", function() {
     VisualizeQuartets(BalancedTree(10), CollapseNode(PectinateTree(10), 19),
                      style = 'label', precision = 1)
   })
-  expect_doppelganger("VQ-tworow", function() {
+  vdiffr::expect_doppelganger("VQ-tworow", function() {
     # Keep original plotting parameters:
     origPar <- par(mfrow = c(2, 2))
     VisualizeQuartets(BalancedTree(10), CollapseNode(PectinateTree(10), 19),
@@ -13,7 +14,7 @@ test_that("VizualiseQuartets()", {
                      spectrum = c(rep('red', 100), 'green'))
     par(origPar)
   })
-  expect_doppelganger("VQ-size", function() {
+  vdiffr::expect_doppelganger("VQ-size", function() {
     VisualizeQuartets(BalancedTree(20), CollapseNode(PectinateTree(20), 29:33),
                      style = 'size', scale = 2)
   })
